@@ -1,4 +1,4 @@
-from .types import t_scheduler, t_output, t_add, t_update
+from .types import t_scheduler, t_output, t_add, t_update, t_delete
 from .runner.env_var import n_env
 from .manager import Manager
 import pretty_cron
@@ -59,14 +59,14 @@ class Scheduler:
         if raw:
             json_filtered = []
             for item in json_data:
-                if item["type"] == self.role:
+                if item["type"] == self.role and item["status"] != t_delete:
                     print(item)
                     json_filtered.append(item)
                 return json_filtered
         else:
             for item in json_data:
                 kind = None
-                if item["type"] == self.role:
+                if item["type"] == self.role and item["status"] != t_delete:
                     cron_string = pretty_cron.prettify_cron(item["value"])
                     kind = f"scheduler {cron_string}"
                     path = (
